Documentation
¶
Index ¶
Constants ¶
const ( // Q series vGPU Q Series = iota + 81 // A series vGPU A = iota + 64 // B series vGPU B // C series vGPU C )
const ( // AttributeMediaExtensions holds the string representation for the +me MIG profile attribute. AttributeMediaExtensions = "ME" // AttributeNoMediaExtensions holds the string representation for the -me MIG profile attribute. AttributeNoMediaExtensions = "NOME" // AttributeMediaExtensionsAll holds the string representation for the +me.all MIG profile attribute. AttributeMediaExtensionsAll = "MEALL" // AttributeGraphics holds the string representation for the +gfx MIG profile attribute. AttributeGraphics = "GFX" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DeviceID ¶
type DeviceID uint32
DeviceID represents a GPU Device ID as read from a GPUs PCIe config space.
func NewDeviceID ¶
NewDeviceID constructs a new 'DeviceID' from the device and vendor values pulled from a GPUs PCIe config space.
func NewDeviceIDFromString ¶
NewDeviceIDFromString constructs a 'DeviceID' from its string representation.
type Series ¶
type Series byte
Series represents the 'series' a vGPU type belongs to. vGPU types are grouped into series according to the different classes of workload for which they are optimized. Each series is identified by the last letter of the vGPU type name (i.e. A100-5C is a 'C-Series' vGPU type).
type VGPUConfig ¶
VGPUConfig holds a map of strings representing a vGPU type to a count of that type. It is meant to represent the set of vGPU types (and how many of a particular type) should be instantiated on the GPU.
func (VGPUConfig) AssertValid ¶
func (v VGPUConfig) AssertValid() error
AssertValid checks if all the vGPU types making up a 'VGPUConfig' are valid
func (VGPUConfig) Contains ¶
func (v VGPUConfig) Contains(vgpuType string) bool
Contains checks if the provided 'vgpuType' is part of the 'VGPUConfig'.
func (VGPUConfig) Equals ¶
func (v VGPUConfig) Equals(config VGPUConfig) bool
Equals checks if two 'VGPUConfig's are equal. Equality is determined by comparing the vGPU types contained in each 'VGPUConfig'.
type VGPUType ¶
VGPUType represents a specific vGPU type. Time-sliced vGPU types appear as <gpu>-<gb><series>. MIG-backed vGPU types appear as <gpu>-<g>-<gb><series>[ME, NOME, MEALL, GFX]. Examples include "A100-40C", "A100D-80C", "A100-1-5C", "A100-1-5CME", "DC-1-24CGFX" etc.
func ParseVGPUType ¶
ParseVGPUType converts a string representation of a VGPUType into an object.